==> everycomp-1.20-2.9.12-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mcaw/MacawFencesModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mcaw;

import net.kikoz.mcwfences.MacawsFences;
import net.kikoz.mcwfences.init.BlockInit;
import net.kikoz.mcwfences.objects.FenceHitbox;
import net.mehvahdjukaar.every_compat.api.RenderLayer;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.every_compat.misc.CompatSpritesHelper;
import net.mehvahdjukaar.moonlight.api.set.leaves.LeavesType;
import net.mehvahdjukaar.moonlight.api.set.leaves.LeavesTypeRegistry;
import net.mehvahdjukaar.moonlight.api.set.leaves.VanillaLeavesTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1297;
import net.minecraft.class_1761;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2349;
import net.minecraft.class_2354;
import net.minecraft.class_2680;
import net.minecraft.class_3481;
import net.minecraft.class_3489;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import org.jetbrains.annotations.NotNull;

//SUPPORT v1.2.0+
public class MacawFencesModule extends SimpleModule {

    public final SimpleEntrySet<LeavesType, class_2248> hedges;
    public final SimpleEntrySet<WoodType, class_2248> highleyGates;
    public final SimpleEntrySet<WoodType, class_2248> horseFences;
    public final SimpleEntrySet<WoodType, class_2248> picketFences;
    public final SimpleEntrySet<WoodType, class_2248> pyramidGates;
    public final SimpleEntrySet<WoodType, class_2248> stockadeFences;
    public final SimpleEntrySet<WoodType, class_2248> wiredFences;

    public MacawFencesModule(String modId) {
        super(modId, "mcf");
        class_5321<class_1761> tab = MacawsFences.FENCESGROUP;

        picketFences = SimpleEntrySet.builder(WoodType.class, "picket_fence",
                        () -> BlockInit.OAK_PICKET_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.4F, 2.0F).method_22488())
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(picketFences);

        stockadeFences = SimpleEntrySet.builder(WoodType.class, "stockade_fence",
                        () -> BlockInit.OAK_STOCKADE_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.4F, 2.0F).method_22488())
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(stockadeFences);

        horseFences = SimpleEntrySet.builder(WoodType.class, "horse_fence",
                        () -> BlockInit.OAK_HORSE_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.4F, 2.0F).method_22488())
                )
                .requiresChildren("stripped_log") //REASON: textures
                //TEXTURES: log, stripped_log (inventory), planks (inventory)
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(horseFences);

        wiredFences = SimpleEntrySet.builder(WoodType.class, "wired_fence",
                        () -> BlockInit.OAK_WIRED_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new WiredFence(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.5F, 2.5F).method_22488())
                )
                //TEXTURES: log
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .setRenderType(RenderLayer.CUTOUT)
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(wiredFences);

        pyramidGates = SimpleEntrySet.builder(WoodType.class, "pyramid_gate",
                        () -> BlockInit.OAK_PYRAMID_GATE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2349(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.4F, 2.0F).method_22488(), w.toVanillaOrOak())
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_25147, class_7924.field_41254)
                .addTag(class_3481.field_25148, class_7924.field_41254)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(pyramidGates);

        highleyGates = SimpleEntrySet.builder(WoodType.class, "highley_gate",
                        () -> BlockInit.OAK_HIGHLEY_GATE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2349(Utils.copyPropertySafe(w.planks)
                                .method_9629(1.4F, 2.0F).method_22488(), w.toVanillaOrOak())
                )
                //TEXTURES: log
                .addTag(class_3481.field_25147, class_7924.field_41254)
                .addTag(class_3481.field_25148, class_7924.field_41254)
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(highleyGates);

        hedges = SimpleEntrySet.builder(LeavesType.class, "hedge",
                        () -> BlockInit.OAK_HEDGE, () -> VanillaLeavesTypes.OAK,
                        l -> new FenceHitbox(Utils.copyPropertySafe(l.leaves).method_9631((s) -> 0)
                                .method_9629(0.2F, 0.3F).method_22488()
                                .method_31710(l.leaves.method_26403()))
                )
                //TEXTURES: leaves
                .addTag(class_3481.field_33714, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_15504, class_7924.field_41254)
                .addTag(class_3489.field_15560, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentTint()
                .addModelTransform(m -> m.replaceWithTextureFromChild("mcwfences:block/oak_leaves",
                        "leaves", CompatSpritesHelper.LOOKS_LIKE_LEAF_TEXTURE))
                .setRenderType(RenderLayer.CUTOUT_MIPPED)
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: Below have no leave texture
                .excludeBlockTypes("regions_unexplored", "flowering")
                .build();
        this.addEntry(hedges);
    }

    public static class WiredFence extends class_2354 {

        public WiredFence(class_2251 properties) {
            super(properties);
        }

        //changed. I couldn't help myself
        @Override
        public void method_9548(class_2680 state, @NotNull class_1937 level, @NotNull class_2338 blockPos, @NotNull class_1297 entityIn) {
            if (state.method_11654(field_10905) || state.method_11654(field_10904) || state.method_11654(field_10907) || state.method_11654(field_10903))
                entityIn.method_5643(level.method_48963().method_48830(), 2.0F);
        }
    }

}

==> everycomp-1.21-2.11.11-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mcaw/MacawFencesModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mcaw;

import net.kikoz.mcwfences.MacawsFences;
import net.kikoz.mcwfences.init.BlockInit;
import net.kikoz.mcwfences.objects.FenceHitbox;
import net.mehvahdjukaar.every_compat.api.RenderLayer;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.every_compat.misc.CompatSpritesHelper;
import net.mehvahdjukaar.moonlight.api.set.leaves.LeavesType;
import net.mehvahdjukaar.moonlight.api.set.leaves.VanillaLeavesTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1297;
import net.minecraft.class_1761;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2349;
import net.minecraft.class_2354;
import net.minecraft.class_2680;
import net.minecraft.class_3481;
import net.minecraft.class_3489;
import net.minecraft.class_4970;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import org.jetbrains.annotations.NotNull;

//SUPPORT v1.1.1+
public class MacawFencesModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> highleyGates,
            horseFences,
            picketFences,
            pyramidGates,
            stockadeFences,
            wiredFences;
    public final SimpleEntrySet<LeavesType, class_2248> hedges;

    public MacawFencesModule(String modId) {
        super(modId, "mcf");
        class_5321<class_1761> tab = MacawsFences.FENCESGROUP;

        picketFences = SimpleEntrySet.builder(WoodType.class, "picket_fence",
                        () -> BlockInit.OAK_PICKET_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(copyStandardProperties(w))
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3489.field_16585, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(picketFences);

        stockadeFences = SimpleEntrySet.builder(WoodType.class, "stockade_fence",
                        () -> BlockInit.OAK_STOCKADE_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(copyStandardProperties(w))
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3489.field_16585, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(stockadeFences);

        horseFences = SimpleEntrySet.builder(WoodType.class, "horse_fence",
                        () -> BlockInit.OAK_HORSE_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2354(copyStandardProperties(w))
                )
                .requiresChildren("stripped_log") //REASON: textures
                //TEXTURES: log, stripped_log (inventory), planks (inventory)
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3489.field_16585, class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(horseFences);

        wiredFences = SimpleEntrySet.builder(WoodType.class, "wired_fence",
                        () -> BlockInit.OAK_WIRED_FENCE, () -> VanillaWoodTypes.OAK,
                        w -> new WiredFence(copyStandardProperties(w))
                )
                //TEXTURES: log
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3489.field_16585, class_7924.field_41197)
                .setTabKey(tab)
                .setRenderType(RenderLayer.CUTOUT)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(wiredFences);

        pyramidGates = SimpleEntrySet.builder(WoodType.class, "pyramid_gate",
                        () -> BlockInit.OAK_PYRAMID_GATE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2349(w.toVanillaOrOak(), copyStandardProperties(w))
                )
                //TEXTURES: log, planks
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_25148, class_7924.field_41254)
                .addTag(class_3481.field_25147, class_7924.field_41254)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(pyramidGates);

        highleyGates = SimpleEntrySet.builder(WoodType.class, "highley_gate",
                        () -> BlockInit.OAK_HIGHLEY_GATE, () -> VanillaWoodTypes.OAK,
                        w -> new class_2349(w.toVanillaOrOak(), copyStandardProperties(w))
                )
                //TEXTURES: log
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_25148, class_7924.field_41254)
                .addTag(class_3481.field_25147, class_7924.field_41254)
                .setTabKey(tab)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                //REASON: take a look at their //TEXTURES, you'll see why. Excluded!
                .excludeBlockTypes("terrestria", "sakura", "yucca_palm")
                .excludeBlockTypes("betternether", "nether_mushroom", "nether_reed")
                .build();
        this.addEntry(highleyGates);

        hedges = SimpleEntrySet.builder(LeavesType.class, "hedge",
                        () -> BlockInit.OAK_HEDGE, () -> VanillaLeavesTypes.OAK,
                        l -> new FenceHitbox(Utils.copyPropertySafe(l.leaves).method_9631((s) -> 0)
                                .method_9629(0.2F, 0.3F).method_22488()
                                .method_31710(l.leaves.method_26403()))
                )
                //TEXTURES: leaves
                .addModelTransform(m -> m.replaceWithTextureFromChild("mcwfences:block/oak_leaves",
                        "leaves", CompatSpritesHelper.LOOKS_LIKE_LEAF_TEXTURE))
                .addTag(class_3481.field_33714, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .addTag(class_3481.field_15504, class_7924.field_41254)
                .addTag(class_3489.field_15560, class_7924.field_41197)
                .setTabKey(tab)
                .setRenderType(RenderLayer.CUTOUT_MIPPED)
                .defaultRecipe()
                .copyParentDrop() //REASON: ensure blocks's dropping when Diagonal Fences is installed
                .copyParentTint()
                //REASON: Below have no leave texture
                .excludeBlockTypes("regions_unexplored", "flowering")
                .build();
        this.addEntry(hedges);
    }

    private class_4970.class_2251 copyStandardProperties(WoodType woodType) {
        return Utils.copyPropertySafe(woodType.planks).method_9629(1.4F, 2.0F).method_22488();
    }

    public static class WiredFence extends class_2354 {

        public WiredFence(class_2251 properties) {
            super(properties);
        }

        //changed. I couldn't help myself
        @Override
        public void method_9548(class_2680 state, @NotNull class_1937 level, @NotNull class_2338 blockPos, @NotNull class_1297 entityIn) {
            if (state.method_11654(field_10905) || state.method_11654(field_10904) || state.method_11654(field_10907) || state.method_11654(field_10903))
                entityIn.method_5643(level.method_48963().method_48830(), 2.0F);
        }
    }

}
